tlslite.messages.RecordHeader2

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Package tlslite :: Module messages :: Class RecordHeader2 |
[hide private]
[frames] | no frames]

# Class RecordHeader2

source code

Instance Methods | [hide private]
__init__(self) | source code
parse(self, p) | source code

Home | Trees | Indices | Help |
--- | --- | --- | --- | ---

Generated by Epydoc 3.0.1 on Thu Sep 27 16:50:12 2012 | http://epydoc.sourceforge.net